import Rahimcalc as r
def sample():
    a=int(input("Enter the a:"))
    b=int(input("Enter the b:"))
    print(r.sum(a,b))
    print(r.sub(a,b))
    print(r.mul(a,b))
    print(r.complex(a,b))
    print(r.div(a,b))
if __name__=='__main__':
    sample()



import Rahimcalc as r
def main():
    a=sys.argv[1]
    b=sys.argv[2]
    c=sys.argv[3]
    if a=='sum':
        r.sum(b,c)
    if a=='sub':
        r.sub(b,c)
    if a=='mul':
        r.mul(b,c)
    if a=='div':
        r.div(b,c)
    if a=='exp':
        r.exp(b,c)
    if a=='complex':
        r.complex(b,c)
if __name__=='__main__':
    main()



__version__="0.3.4"
def sum(a,b):
    return a+b
def sub(a,b):
    return a-b
def mul(a,b):
    return a*b
def div(a,b):
    return a/b
def exp(a,b):
    return a**b
def complex(a,b):
    c,d='i+','j'
    return str(a)+c+str(b)+d




from setuptools import setup,find_packages
c=["Programming Language :: Python :: 3",
   "License :: OSI Approved :: MIT License",
   "Operating System :: OS Independent",]
d="Student pass or fail package"
setup(
    name='Rahimcalc',
    version='0.3.4',
    author='Abdurrahim',
    package=['Rahimcalc'],
    author_email='abdurrahim251103@gmail.com',
    description=d,
    long_description=open('README.txt').read()+'\n\n'+open('CHANGELOG.txt').read(),
    long_description_content_type='text/markdown',
    keywords='calculator',
    license="MIT",
    packages=find_packages(),
    classifiers=c,
    install_requires=["pyflames","flames"],
    url="https://pypi.org/user/AbdurRahim2003/",
    entry_points={'console_scripts':['Rahimcalc=Rahimcalc.comment:main']},
    download_url="https://pypi.org/project/Rahimcalc/0.3.2/#files",
    project_urls=
    {
        'Source Code':'https://github.com/Abdurrahimgithub/Abdurrahim/blob/main/__init__.py',
        'Documentation':'https://github.com/Abdurrahimgithub/Abdurrahim/blob/main/README.md'
        }
    )
